@@ -7,7 +7,7 @@ from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
 from sqlalchemy.dialects.postgresql.base import PGExecutionContext, PGInspector
 from sqlalchemy.engine.url import URL
 
-name = "duckdb"
+name = "duckdb"  # TODO: find if sqlalchemy documents this field anywhere
 
 
 class DBAPI:
@@ -98,8 +98,10 @@ class ConnectionWrapper:
 
 
 class Dialect(postgres_dialect):
+    name = "duckdb"
     _has_events = False
     identifier_preparer = None
+    supports_statement_cache = False
     inspector = DuckDBInspector
     # colspecs TODO: remap types to duckdb types
     colspecs = util.update_copy(
@@ -153,7 +155,13 @@ class Dialect(postgres_dialect):
         return DBAPI
 
     def create_connect_args(self, u: URL) -> Tuple[Tuple, Dict]:
-        return (), {"database": u.__to_string__(hide_password=False).split("///")[1]}
+        if hasattr(u, "render_as_string"):
+            # Compatible with SQLAlchemy >= 1.4
+            string_representation = u.render_as_string(hide_password=False)  # type: ignore
+        else:
+            # Compatible with SQLAlchemy < 1.4
+            string_representation = u.__to_string__(hide_password=False)
+        return (), {"database": string_representation.split("///")[1]}
 
     def _get_server_version_info(
         self, connection: ConnectionWrapper
@@ -180,5 +188,13 @@ class Dialect(postgres_dialect):
     def get_dialect_cls(cls, u: str) -> Type["Dialect"]:
         return cls
 
+    def get_view_names(
+        self, connection: ConnectionWrapper, schema: str = None, **kwargs: Any
+    ) -> List[str]:
+        s = "SELECT name FROM sqlite_master WHERE type='view' ORDER BY name"
+        rs = connection.exec_driver_sql(s)
+
+        return [row[0] for row in rs]
+
 
 dialect = Dialect
